aboutsummaryrefslogtreecommitdiff
path: root/bestflags/generation.py
diff options
context:
space:
mode:
Diffstat (limited to 'bestflags/generation.py')
-rw-r--r--bestflags/generation.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/bestflags/generation.py b/bestflags/generation.py
index 8e1358ad..6fe851a8 100644
--- a/bestflags/generation.py
+++ b/bestflags/generation.py
@@ -28,7 +28,7 @@ class Generation(object):
"""A generation of a framework run.
The base class of generation. Concrete subclasses, e.g., GAGeneration should
override the Next and Improve method to implement algorithm specific
applications.
"""
@@ -111,7 +111,7 @@ class Generation(object):
return True
- def Improve(self):
+ def Improved(self):
"""True if this generation has improvement upon its parent generation.
Raises:
@@ -28,7 +28,7 @@ class Generation(object):
"""A generation of a framework run.
The base class of generation. Concrete subclasses, e.g., GAGeneration should
- override the Next and Improve method to implement algorithm specific
+ override the Next and Improved method to implement algorithm specific
applications.
"""